summaryrefslogtreecommitdiff
path: root/common/src
diff options
context:
space:
mode:
Diffstat (limited to 'common/src')
-rw-r--r--common/src/txe_queue_create.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/common/src/txe_queue_create.c b/common/src/txe_queue_create.c
index 68d3540a..2d91cc9f 100644
--- a/common/src/txe_queue_create.c
+++ b/common/src/txe_queue_create.c
@@ -178,8 +178,8 @@ TX_THREAD *thread_ptr;
status = TX_SIZE_ERROR;
}
- /* Check for an invalid message size - greater than 16. */
- else if (message_size > TX_16_ULONG)
+ /* Check for an invalid message size - greater than TX_QUEUE_MESSAGE_MAX_SIZE 16 by default. */
+ else if (message_size > TX_QUEUE_MESSAGE_MAX_SIZE)
{
/* Invalid message size specified. */